import { ApolloClient, ApolloLink, HttpLink, InMemoryCache } from "@apollo/client";
import { withScalars } from 'apollo-link-scalars';
import { buildClientSchema, IntrospectionQuery } from 'graphql';
import { DateTimeResolver } from 'graphql-scalars';
import introspectionResult from "../../generated/graphql.schema.json";

const schema = buildClientSchema(
  (introspectionResult as unknown) as IntrospectionQuery
);

const httpLink = new HttpLink({
  uri: "/api/graphql",
});

const typesMap = {
  DateTime: DateTimeResolver,
};
const link = ApolloLink.from([
  (withScalars({ schema, typesMap }) as unknown) as ApolloLink,
  httpLink,
]);

export function createApolloClient() {
  return new ApolloClient({
    ssrMode: typeof window === "undefined",
    link,
    cache: new InMemoryCache(),
  });
}